@@ -37,7 +37,11 @@ public:
 
     template <int RTYPE, template <class> class StoragePolicy >
     operator Vector<RTYPE, StoragePolicy>() const {
-        return Rf_allocVector(RTYPE, size) ;
+        // Explicitly protect temporary vector to avoid false positive
+        // with rchk (#892)
+        Shield<SEXP> x(Rf_allocVector(RTYPE, size));
+        Vector<RTYPE, PreserveStorage> ret(x);
+        return ret;
     }
 
 private:
@@ -58,7 +62,11 @@ public:
 
     template <int RTYPE, template <class> class StoragePolicy >
     operator Matrix<RTYPE, StoragePolicy>() const {
-        return Rf_allocMatrix(RTYPE, nr, nc);
+        // Explicitly protect temporary matrix to avoid false positive
+        // with rchk (#892)
+        Shield<SEXP> x(Rf_allocMatrix(RTYPE, nr, nc));
+        Matrix<RTYPE, PreserveStorage> ret(x);
+        return ret;
     }
 
 private:
